searchData={"items":[{"type":"module","title":"NLdoc.SpecDef.Schema","doc":"This module sets some defaults over the Ecto schema for the NLdoc spec.\n\n1. Use this in all schemas for the NLdoc spec, instead of `use Ecto.Schema` or `use TypedEctoSchema`:\n    `use NLdoc.SpecDef.Schema, type: \"https://spec.nldoc.nl/Resource/Foo\"`\n2. Implement the `changeset/2` function in the schema module.\n3. Make sure to add `@cast_opts` to all calls to `cast/4` or `cast_embed/3` or `cast_polymorphic_embed/3`,\n   as it ensures strings that only contain whitespace are accepted as valid.\n\nNote: the `type` option is required and must be a string. It is the resource type of the schema.\nIt will be available as `@resource_type` in the schema module and through the `resource_type/0` function on the schema module.","ref":"NLdoc.SpecDef.Schema.html"},{"type":"module","title":"Example - NLdoc.SpecDef.Schema","doc":"defmodule Example do\n      @moduledoc false\n\n      use NLdoc.SpecDef.Schema, type: \"https://spec.foo.com/example\"\n\n      typed_embedded_schema null: false do\n        field :type, :string, default: @resource_type\n        field :message, :string\n      end\n\n      def changeset(object, attrs) do\n        fields = [:type, :message]\n\n        object\n        |> cast(attrs, fields, @cast_opts)\n        |> validate_required(fields)\n        |> validate_inclusion(:type, [@resource_type])\n      end\n    end","ref":"NLdoc.SpecDef.Schema.html#module-example"},{"type":"macro","title":"NLdoc.SpecDef.Schema.def_constructor/1","doc":"This macro defines the `new/1` and `new!/1` functions for the schema module that create a new document from a template,\nwhich essentially functions like an input-validating constructor for the struct defined by the schema module.","ref":"NLdoc.SpecDef.Schema.html#def_constructor/1"},{"type":"extras","title":"NLdoc.SpecDef","doc":"# NLdoc.SpecDef","ref":"readme.html"},{"type":"extras","title":"Installation - NLdoc.SpecDef","doc":"The package can be installed by adding `nldoc_spec_def` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:nldoc_spec_def, \"~> 1.0.0\"}\n  ]\nend\n```\n\nDocumentation is generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm/nldoc_spec_def).","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [1.0.4](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_spec_def/compare/1.0.3...1.0.4) (2025-05-12)","ref":"changelog.html"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency ex_doc to v0.38.1 ([db82fa2](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_spec_def/commit/db82fa23c7bc43951b16ad0a2e5bf9868b3298a2))\n\n## [1.0.3](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_spec_def/compare/1.0.2...1.0.3) (2025-05-12)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency ex_doc to ~> 0.38 ([785ef43](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_spec_def/commit/785ef4361f80f261d296dd903f09153b0fcd8b12))\n\n## [1.0.2](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_spec_def/compare/1.0.1...1.0.2) (2025-04-17)","ref":"changelog.html#bug-fixes-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* **deps:** update dependency credo to v1.7.12 ([2de179f](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_spec_def/commit/2de179fabb64b0cf0e3ae27dad64a5eb7e71ae89))\n\n## [1.0.1](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_spec_def/compare/1.0.0...1.0.1) (2025-04-09)","ref":"changelog.html#bug-fixes-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* module namespace ([1dc75da](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_spec_def/commit/1dc75da88140cf78f64e0da7ffd9fcb8c675f703))\n\n# 1.0.0 (2025-04-08)","ref":"changelog.html#bug-fixes-3"},{"type":"extras","title":"Features - Changelog","doc":"* initial commit ([524de22](https://gitlab.com/logius/nldoc/lib/elixir/nldoc_spec_def/commit/524de2251be4de164674fc880d12328d2e15f8f6))","ref":"changelog.html#features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.0"}}